pub struct QuditTensor {
pub indices: Vec<TensorIndex>,
pub expression: ExpressionId,
pub param_info: ParamInfo,
}Fields
indices: Vec<TensorIndex>expression: ExpressionIdparam_info: ParamInfoImplementations
Sourceimpl QuditTensor
impl QuditTensor
Sourcepub fn new(
indices: Vec<TensorIndex>,
expression: ExpressionId,
param_info: ParamInfo,
) -> Self
pub fn new( indices: Vec<TensorIndex>, expression: ExpressionId, param_info: ParamInfo, ) -> Self
Construct a new tensor object from a tensor expression and param indices.
pub fn num_indices(&self) -> usize
pub fn shape(&self) -> GenerationShape
Sourcepub fn batch_indices(&self) -> Vec<usize>
pub fn batch_indices(&self) -> Vec<usize>
Returns a vector of index IDs for all batch legs of the tensor.
Sourcepub fn output_indices(&self) -> Vec<usize>
pub fn output_indices(&self) -> Vec<usize>
Returns a vector of index IDs for all output legs of the tensor.
Sourcepub fn input_indices(&self) -> Vec<usize>
pub fn input_indices(&self) -> Vec<usize>
Returns a vector of index IDs for all input legs of the tensor.
Sourcepub fn batch_sizes(&self) -> Vec<usize>
pub fn batch_sizes(&self) -> Vec<usize>
Returns a vector of sizes for all batch legs of the tensor.
Sourcepub fn output_sizes(&self) -> Vec<usize>
pub fn output_sizes(&self) -> Vec<usize>
Returns a vector of sizes for all output legs of the tensor.
Sourcepub fn input_sizes(&self) -> Vec<usize>
pub fn input_sizes(&self) -> Vec<usize>
Returns a vector of sizes for all input legs of the tensor.